pub struct PeerConfig {
pub node_id: u64,
pub address: String,
}Fields
node_id: u64address: StringTrait Implementations
Sourceimpl Archive for PeerConfig
impl Archive for PeerConfig
Sourcetype Archived = ArchivedPeerConfig
type Archived = ArchivedPeerConfig
The archived representation of this type. Read more
Sourcetype Resolver = PeerConfigResolver
type Resolver = PeerConfigResolver
The resolver for this type. It must contain all the additional information from serializing
needed to make the archived type from the normal type.
Sourceimpl Clone for PeerConfig
impl Clone for PeerConfig
Sourcefn clone(&self) -> PeerConfig
fn clone(&self) -> PeerConfig
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PeerConfig
impl Debug for PeerConfig
Sourceimpl<'de> Deserialize<'de> for PeerConfig
impl<'de> Deserialize<'de> for PeerConfig
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl<__D: Fallible + ?Sized> Deserialize<PeerConfig, __D> for Archived<PeerConfig>
impl<__D: Fallible + ?Sized> Deserialize<PeerConfig, __D> for Archived<PeerConfig>
Sourcefn deserialize(&self, deserializer: &mut __D) -> Result<PeerConfig, __D::Error>
fn deserialize(&self, deserializer: &mut __D) -> Result<PeerConfig, __D::Error>
Deserializes using the given deserializer