pub struct ExpansionContext {
pub struct_name: String,
pub fields: Vec<(String, String)>,
pub attributes: Vec<String>,
pub other_cells: Vec<String>,
}Fields
struct_name: Stringfields: Vec<(String, String)>attributes: Vec<String>other_cells: Vec<String>Trait Implementations
Sourceimpl Archive for ExpansionContext
impl Archive for ExpansionContext
Sourcetype Archived = ArchivedExpansionContext
type Archived = ArchivedExpansionContext
The archived representation of this type. Read more
Sourcetype Resolver = ExpansionContextResolver
type Resolver = ExpansionContextResolver
The resolver for this type. It must contain all the additional information from serializing
needed to make the archived type from the normal type.
Sourceimpl Clone for ExpansionContext
impl Clone for ExpansionContext
Sourcefn clone(&self) -> ExpansionContext
fn clone(&self) -> ExpansionContext
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ExpansionContext
impl Debug for ExpansionContext
Sourceimpl<'de> Deserialize<'de> for ExpansionContext
impl<'de> Deserialize<'de> for ExpansionContext
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl<__D: Fallible + ?Sized> Deserialize<ExpansionContext, __D> for Archived<ExpansionContext>
impl<__D: Fallible + ?Sized> Deserialize<ExpansionContext, __D> for Archived<ExpansionContext>
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<ExpansionContext, __D::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<ExpansionContext, __D::Error>
Deserializes using the given deserializer