pub struct MacroInfo {
pub name: String,
pub kind: MacroKind,
pub description: String,
pub dependencies: Vec<String>,
}Fields
name: Stringkind: MacroKinddescription: Stringdependencies: Vec<String>Trait Implementations
Sourceimpl Archive for MacroInfo
impl Archive for MacroInfo
Sourcetype Archived = ArchivedMacroInfo
type Archived = ArchivedMacroInfo
The archived representation of this type. Read more
Sourcetype Resolver = MacroInfoResolver
type Resolver = MacroInfoResolver
The resolver for this type. It must contain all the additional information from serializing
needed to make the archived type from the normal type.
Sourceimpl<'de> Deserialize<'de> for MacroInfo
impl<'de> Deserialize<'de> for MacroInfo
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more