pub struct MetricsSnapshot {
pub requests_total: u64,
pub requests_success: u64,
pub requests_failed: u64,
pub latency_histogram: Vec<u64>,
pub connections_active: u64,
pub bytes_sent: u64,
pub bytes_received: u64,
}Fields
requests_total: u64requests_success: u64requests_failed: u64latency_histogram: Vec<u64>connections_active: u64bytes_sent: u64bytes_received: u64Trait Implementations
Sourceimpl Archive for MetricsSnapshot
impl Archive for MetricsSnapshot
Sourcetype Archived = ArchivedMetricsSnapshot
type Archived = ArchivedMetricsSnapshot
The archived representation of this type. Read more
Sourcetype Resolver = MetricsSnapshotResolver
type Resolver = MetricsSnapshotResolver
The resolver for this type. It must contain all the additional information from serializing
needed to make the archived type from the normal type.
Sourceimpl Clone for MetricsSnapshot
impl Clone for MetricsSnapshot
Sourcefn clone(&self) -> MetricsSnapshot
fn clone(&self) -> MetricsSnapshot
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MetricsSnapshot
impl Debug for MetricsSnapshot
Sourceimpl<'de> Deserialize<'de> for MetricsSnapshot
impl<'de> Deserialize<'de> for MetricsSnapshot
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl<__D: Fallible + ?Sized> Deserialize<MetricsSnapshot, __D> for Archived<MetricsSnapshot>
impl<__D: Fallible + ?Sized> Deserialize<MetricsSnapshot, __D> for Archived<MetricsSnapshot>
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<MetricsSnapshot, __D::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<MetricsSnapshot, __D::Error>
Deserializes using the given deserializer