pub struct FieldDef {
pub name: String,
pub ty: String,
pub attributes: Vec<String>,
pub nullable: bool,
pub default_value: Option<String>,
}Expand description
Field definition in a schema.
Fields
name: Stringty: Stringattributes: Vec<String>nullable: booldefault_value: Option<String>Trait Implementations
Sourceimpl Archive for FieldDef
impl Archive for FieldDef
Sourcetype Archived = ArchivedFieldDef
type Archived = ArchivedFieldDef
The archived representation of this type. Read more
Sourcetype Resolver = FieldDefResolver
type Resolver = FieldDefResolver
The resolver for this type. It must contain all the additional information from serializing
needed to make the archived type from the normal type.
Sourceimpl<'de> Deserialize<'de> for FieldDef
impl<'de> Deserialize<'de> for FieldDef
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl StructuralPartialEq for FieldDef