pub struct SchemaMetadata {
pub description: Option<String>,
pub author: Option<String>,
pub created_at: Option<u64>,
pub updated_at: Option<u64>,
pub constraints: Vec<SchemaConstraint>,
}Expand description
Metadata for schema documentation and constraints.
Fields
description: Option<String>created_at: Option<u64>updated_at: Option<u64>constraints: Vec<SchemaConstraint>Trait Implementations
Sourceimpl Archive for SchemaMetadata
impl Archive for SchemaMetadata
Sourcetype Archived = ArchivedSchemaMetadata
type Archived = ArchivedSchemaMetadata
The archived representation of this type. Read more
Sourcetype Resolver = SchemaMetadataResolver
type Resolver = SchemaMetadataResolver
The resolver for this type. It must contain all the additional information from serializing
needed to make the archived type from the normal type.
Sourceimpl Clone for SchemaMetadata
impl Clone for SchemaMetadata
Sourcefn clone(&self) -> SchemaMetadata
fn clone(&self) -> SchemaMetadata
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SchemaMetadata
impl Debug for SchemaMetadata
Sourceimpl Default for SchemaMetadata
impl Default for SchemaMetadata
Sourcefn default() -> SchemaMetadata
fn default() -> SchemaMetadata
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for SchemaMetadata
impl<'de> Deserialize<'de> for SchemaMetadata
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl<__D: Fallible + ?Sized> Deserialize<SchemaMetadata, __D> for Archived<SchemaMetadata>where
Option<String>: Archive,
Archived<Option<String>>: Deserialize<Option<String>, __D>,
Option<u64>: Archive,
Archived<Option<u64>>: Deserialize<Option<u64>, __D>,
Vec<SchemaConstraint>: Archive,
Archived<Vec<SchemaConstraint>>: Deserialize<Vec<SchemaConstraint>, __D>,
impl<__D: Fallible + ?Sized> Deserialize<SchemaMetadata, __D> for Archived<SchemaMetadata>where
Option<String>: Archive,
Archived<Option<String>>: Deserialize<Option<String>, __D>,
Option<u64>: Archive,
Archived<Option<u64>>: Deserialize<Option<u64>, __D>,
Vec<SchemaConstraint>: Archive,
Archived<Vec<SchemaConstraint>>: Deserialize<Vec<SchemaConstraint>, __D>,
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<SchemaMetadata, __D::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<SchemaMetadata, __D::Error>
Deserializes using the given deserializer
Sourceimpl PartialEq for SchemaMetadata
impl PartialEq for SchemaMetadata
Sourceimpl Serialize for SchemaMetadata
impl Serialize for SchemaMetadata
impl StructuralPartialEq for SchemaMetadata